# Tripo MCP Server

Tripo MCP provides an interface between AI assistants and [Tripo AI](https://www.tripo3d.ai) via [Model Context Protocol (MCP)](https://github.com/anthropics/anthropic-cookbook/tree/main/mcp). 

> **Note:** This project is in alpha. Currently, it supports Tripo Blender Addon integration.

## Current Features

- Generate 3D asset from natural language using Tripo's API and import to Blender
- Compatible with Claude and other MCP-enabled AI assistants

## Quick Start

### Prerequisites
- Python 3.10+
- [Blender](https://www.blender.org/download/)
- [Tripo AI Blender Addon](https://www.tripo3d.ai/app/home)
- Claude for Desktop or Cursor IDE

### Installation

1. Install Tripo AI Blender Addon from [Tripo AI's website](https://www.tripo3d.ai/app/home)

2. Configure the MCP server in Claude Desktop or Cursor.

3. Happy creating in 3D! E.g., "Generate a 3D model of a futuristic chair".

## Acknowledgements

- [Tripo AI](https://www.tripo3d.ai)
- [blender-mcp](https://github.com/ahujasid/blender-mcp) project for inspiration
